==> haskell-regex-posix-0.96.0.1-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-regex-posix.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 regex-posix
version:              0.96.0.1
visibility:           public
id:                   regex-posix-0.96.0.1-3tnfXrSqQrb7MJMFtuTwG8
key:                  regex-posix-0.96.0.1-3tnfXrSqQrb7MJMFtuTwG8
license:              BSD-3-Clause
copyright:            Copyright (c) 2007-2010, Christopher Kuklewicz
maintainer:           hvr@gnu.org, Andreas Abel
author:               Christopher Kuklewicz
synopsis:             POSIX Backend for "Text.Regex" (regex-base)
description:
    The POSIX regex backend for <//hackage.haskell.org/package/regex-base regex-base>.

    The main appeal of this backend is that it'\''s very lightweight due to its reliance on the ubiquitous <https://pubs.opengroup.org/onlinepubs/9699919799/basedefs/regex.h.html POSIX.2 regex> facility that is provided by the standard C library on most POSIX platforms.

    See also <https://wiki.haskell.org/Regular_expressions> for more information.

category:             Text
abi:                  9e448dd69a046bc6063f3c3ec0cf352e
exposed:              True
exposed-modules:
    Text.Regex.Posix Text.Regex.Posix.ByteString
    Text.Regex.Posix.ByteString.Lazy Text.Regex.Posix.Sequence
    Text.Regex.Posix.String Text.Regex.Posix.Wrap

hidden-modules:       Paths_regex_posix
import-dirs:          /usr/lib/ghc-9.0.2/site-local/regex-posix-0.96.0.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/regex-posix-0.96.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/regex-posix-0.96.0.1
hs-libraries:         HSregex-posix-0.96.0.1-3tnfXrSqQrb7MJMFtuTwG8
depends:
    array-0.5.4.0 base-4.15.1.0 bytestring-0.10.12.1 containers-0.6.4.1
    regex-base-0.94.0.2-9bnMACbSerDB0WfT2SIplq

haddock-interfaces:   /usr/share/doc/haskell-regex-posix/html/regex-posix.haddock
haddock-html:         /usr/share/doc/haskell-regex-posix/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-regex-posix-0.96.0.1-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-regex-posix.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 regex-posix
version:              0.96.0.1
visibility:           public
id:                   regex-posix-0.96.0.1-Genc39RUTH74GYzEFB6fWq
key:                  regex-posix-0.96.0.1-Genc39RUTH74GYzEFB6fWq
license:              BSD-3-Clause
copyright:            Copyright (c) 2007-2010, Christopher Kuklewicz
maintainer:           hvr@gnu.org, Andreas Abel
author:               Christopher Kuklewicz
synopsis:             POSIX Backend for "Text.Regex" (regex-base)
description:
    The POSIX regex backend for <//hackage.haskell.org/package/regex-base regex-base>.

    The main appeal of this backend is that it'\''s very lightweight due to its reliance on the ubiquitous <https://pubs.opengroup.org/onlinepubs/9699919799/basedefs/regex.h.html POSIX.2 regex> facility that is provided by the standard C library on most POSIX platforms.

    See also <https://wiki.haskell.org/Regular_expressions> for more information.

category:             Text
abi:                  a36288b821557779d48389510fa7c56a
exposed:              True
exposed-modules:
    Text.Regex.Posix Text.Regex.Posix.ByteString
    Text.Regex.Posix.ByteString.Lazy Text.Regex.Posix.Sequence
    Text.Regex.Posix.String Text.Regex.Posix.Wrap

hidden-modules:       Paths_regex_posix
import-dirs:          /usr/lib/ghc-9.2.8/site-local/regex-posix-0.96.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/regex-posix-0.96.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-regex-posix
hs-libraries:         HSregex-posix-0.96.0.1-Genc39RUTH74GYzEFB6fWq
depends:
    array-0.5.4.0 base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    regex-base-0.94.0.2-6On48UZuN5IJxnL3aRqiWN

haddock-interfaces:   /usr/share/doc/haskell-regex-posix/html/regex-posix.haddock
haddock-html:         /usr/share/doc/haskell-regex-posix/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
